@@ -73,7 +73,7 @@ export interface Dataset {
   main_dttm_col: string;
   // eg. ['["ds", true]', 'ds [asc]']
   order_by_choices?: [string, string][] | null;
-  time_grain_sqla?: string;
+  time_grain_sqla?: [string, string][];
   granularity_sqla?: string;
   datasource_name: string | null;
   name?: string;
@@ -518,7 +518,6 @@ export type ControlFormItemSpec<T extends ControlType = ControlType> = {
   debounceDelay?: number;
 } & (T extends 'Select'
   ? {
-      allowNewOptions?: boolean;
       options: any;
       value?: string;
       defaultValue?: string;
