@@ -24,14 +24,10 @@ import {
   EventAnnotationLayer,
   FilterState,
   FormulaAnnotationLayer,
-  getTimeFormatter,
   IntervalAnnotationLayer,
   isTimeseriesAnnotationResult,
   LegendState,
-  smartDateDetailedFormatter,
-  smartDateFormatter,
   SupersetTheme,
-  TimeFormatter,
   TimeseriesAnnotationLayer,
   TimeseriesDataRecord,
   ValueFormatter,
@@ -554,7 +550,6 @@ export function getPadding(
   yAxisTitlePosition?: string,
   yAxisTitleMargin?: number,
   xAxisTitleMargin?: number,
-  isHorizontal?: boolean,
 ): {
   bottom: number;
   left: number;
@@ -565,52 +560,21 @@ export function getPadding(
     ? TIMESERIES_CONSTANTS.yAxisLabelTopOffset
     : 0;
   const xAxisOffset = addXAxisTitleOffset ? Number(xAxisTitleMargin) || 0 : 0;
-  return getChartPadding(
-    showLegend,
-    legendOrientation,
-    margin,
-    {
-      top:
-        yAxisTitlePosition && yAxisTitlePosition === 'Top'
-          ? TIMESERIES_CONSTANTS.gridOffsetTop + (Number(yAxisTitleMargin) || 0)
-          : TIMESERIES_CONSTANTS.gridOffsetTop + yAxisOffset,
-      bottom: zoomable
-        ? TIMESERIES_CONSTANTS.gridOffsetBottomZoomable + xAxisOffset
-        : TIMESERIES_CONSTANTS.gridOffsetBottom + xAxisOffset,
-      left:
-        yAxisTitlePosition === 'Left'
-          ? TIMESERIES_CONSTANTS.gridOffsetLeft +
-            (Number(yAxisTitleMargin) || 0)
-          : TIMESERIES_CONSTANTS.gridOffsetLeft,
-      right:
-        showLegend && legendOrientation === LegendOrientation.Right
-          ? 0
-          : TIMESERIES_CONSTANTS.gridOffsetRight,
-    },
-    isHorizontal,
-  );
-}
-
-export function getTooltipTimeFormatter(
-  format?: string,
-): TimeFormatter | StringConstructor {
-  if (format === smartDateFormatter.id) {
-    return smartDateDetailedFormatter;
-  }
-  if (format) {
-    return getTimeFormatter(format);
-  }
-  return String;
-}
-
-export function getXAxisFormatter(
-  format?: string,
-): TimeFormatter | StringConstructor | undefined {
-  if (format === smartDateFormatter.id || !format) {
-    return undefined;
-  }
-  if (format) {
-    return getTimeFormatter(format);
-  }
-  return String;
+  return getChartPadding(showLegend, legendOrientation, margin, {
+    top:
+      yAxisTitlePosition && yAxisTitlePosition === 'Top'
+        ? TIMESERIES_CONSTANTS.gridOffsetTop + (Number(yAxisTitleMargin) || 0)
+        : TIMESERIES_CONSTANTS.gridOffsetTop + yAxisOffset,
+    bottom: zoomable
+      ? TIMESERIES_CONSTANTS.gridOffsetBottomZoomable + xAxisOffset
+      : TIMESERIES_CONSTANTS.gridOffsetBottom + xAxisOffset,
+    left:
+      yAxisTitlePosition === 'Left'
+        ? TIMESERIES_CONSTANTS.gridOffsetLeft + (Number(yAxisTitleMargin) || 0)
+        : TIMESERIES_CONSTANTS.gridOffsetLeft,
+    right:
+      showLegend && legendOrientation === LegendOrientation.Right
+        ? 0
+        : TIMESERIES_CONSTANTS.gridOffsetRight,
+  });
 }
