@@ -22,37 +22,42 @@ import { render, RenderOptions } from '@testing-library/react';
 import { ThemeProvider, supersetTheme } from '@superset-ui/core';
 import { BrowserRouter } from 'react-router-dom';
 import { Provider } from 'react-redux';
-import {
-  combineReducers,
-  createStore,
-  applyMiddleware,
-  compose,
-  Store,
-} from 'redux';
-import thunk from 'redux-thunk';
 import { DndProvider } from 'react-dnd';
 import { HTML5Backend } from 'react-dnd-html5-backend';
 import reducerIndex from 'spec/helpers/reducerIndex';
 import { QueryParamProvider } from 'use-query-params';
-import QueryProvider from 'src/views/QueryProvider';
+import { configureStore, Store } from '@reduxjs/toolkit';
+import { api } from 'src/hooks/apiResources/queryApi';
 
 type Options = Omit<RenderOptions, 'queries'> & {
   useRedux?: boolean;
   useDnd?: boolean;
   useQueryParams?: boolean;
   useRouter?: boolean;
-  useQuery?: boolean;
   initialState?: {};
   reducers?: {};
   store?: Store;
 };
 
+export const createStore = (initialState: object = {}, reducers: object = {}) =>
+  configureStore({
+    preloadedState: initialState,
+    reducer: {
+      ...reducers,
+      [api.reducerPath]: api.reducer,
+    },
+    middleware: getDefaultMiddleware =>
+      getDefaultMiddleware().concat(api.middleware),
+    devTools: false,
+  });
+
+export const defaultStore = createStore();
+
 export function createWrapper(options?: Options) {
   const {
     useDnd,
     useRedux,
     useQueryParams,
-    useQuery = true,
     useRouter,
     initialState,
     reducers,
@@ -68,15 +73,9 @@ export function createWrapper(options?: Options) {
       result = <DndProvider backend={HTML5Backend}>{result}</DndProvider>;
     }
 
-    if (useRedux) {
+    if (useRedux || store) {
       const mockStore =
-        store ??
-        createStore(
-          combineReducers(reducers || reducerIndex),
-          initialState || {},
-          compose(applyMiddleware(thunk)),
-        );
-
+        store ?? createStore(initialState, reducers || reducerIndex);
       result = <Provider store={mockStore}>{result}</Provider>;
     }
 
@@ -88,10 +87,6 @@ export function createWrapper(options?: Options) {
       result = <BrowserRouter>{result}</BrowserRouter>;
     }
 
-    if (useQuery) {
-      result = <QueryProvider>{result}</QueryProvider>;
-    }
-
     return result;
   };
 }
