@@ -18,7 +18,7 @@
  */
 import { styled, css, SupersetTheme } from '@superset-ui/core';
 import cx from 'classnames';
-import Interweave from 'interweave';
+import { Interweave } from 'interweave';
 import React, { useCallback, useEffect, useRef, useState } from 'react';
 import Icons from 'src/components/Icons';
 import { ToastType, ToastMeta } from './types';
