@@ -25,6 +25,7 @@ import {
   UNSET_FOCUSED_NATIVE_FILTER,
   SET_HOVERED_NATIVE_FILTER,
   UNSET_HOVERED_NATIVE_FILTER,
+  UPDATE_CASCADE_PARENT_IDS,
 } from 'src/dashboard/actions/nativeFilters';
 import {
   FilterSet,
@@ -116,6 +117,18 @@ export default function nativeFilterReducer(
         ...state,
         hoveredFilterId: undefined,
       };
+
+    case UPDATE_CASCADE_PARENT_IDS:
+      return {
+        ...state,
+        filters: {
+          ...state.filters,
+          [action.id]: {
+            ...state.filters[action.id],
+            cascadeParentIds: action.parentIds,
+          },
+        },
+      };
     // TODO handle SET_FILTER_CONFIG_FAIL action
     default:
       return state;
