@@ -31,19 +31,12 @@ import Select from 'src/components/Select/Select';
 import AsyncSelect from 'src/components/Select/AsyncSelect';
 import rison from 'rison';
 import { LabeledErrorBoundInput } from 'src/components/Form';
+import { noBottomMargin } from 'src/features/reports/ReportModal/styles';
 import InfoTooltip from 'src/components/InfoTooltip';
 import { useSingleViewResource } from 'src/views/CRUD/hooks';
 import { FilterOptions } from './constants';
 import { FilterType, RLSObject, RoleObject, TableObject } from './types';
 
-const noMargins = css`
-  margin: 0;
-
-  .ant-input {
-    margin: 0;
-  }
-`;
-
 const StyledModal = styled(Modal)`
   max-width: 1200px;
   min-width: min-content;
@@ -66,17 +59,9 @@ const StyledSectionContainer = styled.div`
   padding: ${({ theme }) =>
     `${theme.gridUnit * 3}px ${theme.gridUnit * 4}px ${theme.gridUnit * 2}px`};
 
-  label,
-  .control-label {
-    display: inline-block;
+  label {
     font-size: ${({ theme }) => theme.typography.sizes.s}px;
-    color: ${({ theme }) => theme.colors.grayscale.base};
-    vertical-align: middle;
-  }
-
-  .info-solid-small {
-    vertical-align: middle;
-    padding-bottom: ${({ theme }) => theme.gridUnit / 2}px;
+    color: ${({ theme }) => theme.colors.grayscale.light1};
   }
 `;
 
@@ -84,6 +69,7 @@ const StyledInputContainer = styled.div`
   display: flex;
   flex-direction: column;
   margin: ${({ theme }) => theme.gridUnit}px;
+
   margin-bottom: ${({ theme }) => theme.gridUnit * 4}px;
 
   .input-container {
@@ -93,6 +79,11 @@ const StyledInputContainer = styled.div`
     > div {
       width: 100%;
     }
+
+    label {
+      display: flex;
+      margin-right: ${({ theme }) => theme.gridUnit * 2}px;
+    }
   }
 
   input,
@@ -100,19 +91,17 @@ const StyledInputContainer = styled.div`
     flex: 1 1 auto;
   }
 
+  textarea {
+    height: 100px;
+    resize: none;
+  }
+
   .required {
     margin-left: ${({ theme }) => theme.gridUnit / 2}px;
     color: ${({ theme }) => theme.colors.error.base};
   }
 `;
 
-const StyledTextArea = styled.textarea`
-  height: 100px;
-  resize: none;
-  margin-top: ${({ theme }) => theme.gridUnit}px;
-  border: 1px solid ${({ theme }) => theme.colors.secondary.light3};
-`;
-
 export interface RowLevelSecurityModalProps {
   rule: RLSObject | null;
   addSuccessToast: (msg: string) => void;
@@ -366,11 +355,9 @@ function RowLevelSecurityModal(props: RowLevelSecurityModalProps) {
                 onChange: ({ target }: { target: HTMLInputElement }) =>
                   onTextChange(target),
               }}
-              css={noMargins}
+              css={noBottomMargin}
               label={t('Rule Name')}
               data-test="rule-name-test"
-              tooltipText={t('The name of the rule must be unique')}
-              hasTooltip
             />
           </StyledInputContainer>
 
@@ -446,7 +433,7 @@ function RowLevelSecurityModal(props: RowLevelSecurityModalProps) {
                 onChange: ({ target }: { target: HTMLInputElement }) =>
                   onTextChange(target),
               }}
-              css={noMargins}
+              css={noBottomMargin}
               label={t('Group Key')}
               hasTooltip
               tooltipText={t(
@@ -467,7 +454,7 @@ function RowLevelSecurityModal(props: RowLevelSecurityModalProps) {
                   onChange: ({ target }: { target: HTMLInputElement }) =>
                     onTextChange(target),
                 }}
-                css={noMargins}
+                css={noBottomMargin}
                 label={t('Clause')}
                 hasTooltip
                 tooltipText={t(
@@ -481,7 +468,7 @@ function RowLevelSecurityModal(props: RowLevelSecurityModalProps) {
           <StyledInputContainer>
             <div className="control-label">{t('Description')}</div>
             <div className="input-container">
-              <StyledTextArea
+              <textarea
                 name="description"
                 value={currentRule ? currentRule.description : ''}
                 onChange={event => onTextChange(event.target)}
