@@ -33,7 +33,6 @@ import { URL_PARAMS } from 'src/constants';
 import { Link, withRouter, RouteComponentProps } from 'react-router-dom';
 import Button from 'src/components/Button';
 import { AsyncSelect, Steps } from 'src/components';
-import { Tooltip } from 'src/components/Tooltip';
 import withToasts from 'src/components/MessageToasts/withToasts';
 
 import VizTypeGallery, {
@@ -42,13 +41,10 @@ import VizTypeGallery, {
 import { findPermission } from 'src/utils/findPermission';
 import { UserWithPermissionsAndRoles } from 'src/types/bootstrapTypes';
 import getBootstrapData from 'src/utils/getBootstrapData';
-
-type Dataset = {
-  id: number;
-  table_name: string;
-  description: string;
-  datasource_type: string;
-};
+import {
+  Dataset,
+  DatasetSelectLabel,
+} from 'src/features/datasets/DatasetSelectLabel';
 
 export interface ChartCreationProps extends RouteComponentProps {
   user: UserWithPermissionsAndRoles;
@@ -169,40 +165,10 @@ const StyledContainer = styled.div`
     &&&& .ant-select-selection-placeholder {
       padding-left: ${theme.gridUnit * 3}px;
     }
-  `}
-`;
 
-const TooltipContent = styled.div<{ hasDescription: boolean }>`
-  ${({ theme, hasDescription }) => `
-    .tooltip-header {
-      font-size: ${
-        hasDescription ? theme.typography.sizes.l : theme.typography.sizes.s
-      }px;
-      font-weight: ${
-        hasDescription
-          ? theme.typography.weights.bold
-          : theme.typography.weights.normal
-      };
+    &&&& .ant-select-selection-item {
+      padding-left: ${theme.gridUnit * 3}px;
     }
-
-    .tooltip-description {
-      margin-top: ${theme.gridUnit * 2}px;
-      display: -webkit-box;
-      -webkit-line-clamp: 20;
-      -webkit-box-orient: vertical;
-      overflow: hidden;
-      text-overflow: ellipsis;
-    }
-  `}
-`;
-
-const StyledLabel = styled.span`
-  ${({ theme }) => `
-    position: absolute;
-    left: ${theme.gridUnit * 3}px;
-    right: ${theme.gridUnit * 3}px;
-    overflow: hidden;
-    text-overflow: ellipsis;
   `}
 `;
 
@@ -242,7 +208,6 @@ export class ChartCreation extends React.PureComponent<
     this.changeDatasource = this.changeDatasource.bind(this);
     this.changeVizType = this.changeVizType.bind(this);
     this.gotoSlice = this.gotoSlice.bind(this);
-    this.newLabel = this.newLabel.bind(this);
     this.loadDatasources = this.loadDatasources.bind(this);
     this.onVizTypeDoubleClick = this.onVizTypeDoubleClick.bind(this);
   }
@@ -293,28 +258,15 @@ export class ChartCreation extends React.PureComponent<
     }
   }
 
-  newLabel(item: Dataset) {
-    return (
-      <Tooltip
-        mouseEnterDelay={1}
-        placement="right"
-        title={
-          <TooltipContent hasDescription={!!item.description}>
-            <div className="tooltip-header">{item.table_name}</div>
-            {item.description && (
-              <div className="tooltip-description">{item.description}</div>
-            )}
-          </TooltipContent>
-        }
-      >
-        <StyledLabel>{item.table_name}</StyledLabel>
-      </Tooltip>
-    );
-  }
-
   loadDatasources(search: string, page: number, pageSize: number) {
     const query = rison.encode({
-      columns: ['id', 'table_name', 'description', 'datasource_type'],
+      columns: [
+        'id',
+        'table_name',
+        'datasource_type',
+        'database.database_name',
+        'schema',
+      ],
       filters: [{ col: 'table_name', opr: 'ct', value: search }],
       page,
       page_size: pageSize,
@@ -332,7 +284,7 @@ export class ChartCreation extends React.PureComponent<
       }[] = response.json.result.map((item: Dataset) => ({
         id: item.id,
         value: `${item.id}__${item.datasource_type}`,
-        customLabel: this.newLabel(item),
+        customLabel: DatasetSelectLabel(item),
         label: item.table_name,
       }));
       return {
