@@ -72,10 +72,9 @@ if feature_flags.get("VERSIONED_EXPORT"):
     def export_dashboards(dashboard_file: Optional[str] = None) -> None:
         """Export dashboards to ZIP file"""
         # pylint: disable=import-outside-toplevel
-        from superset.dashboards.commands.export import ExportDashboardsCommand
+        from superset.commands.dashboard.export import ExportDashboardsCommand
         from superset.models.dashboard import Dashboard
 
-        # pylint: disable=assigning-non-slot
         g.user = security_manager.find_user(username="admin")
 
         dashboard_ids = [id_ for (id_,) in db.session.query(Dashboard.id).all()]
@@ -107,10 +106,9 @@ if feature_flags.get("VERSIONED_EXPORT"):
     def export_datasources(datasource_file: Optional[str] = None) -> None:
         """Export datasources to ZIP file"""
         # pylint: disable=import-outside-toplevel
+        from superset.commands.dataset.export import ExportDatasetsCommand
         from superset.connectors.sqla.models import SqlaTable
-        from superset.datasets.commands.export import ExportDatasetsCommand
 
-        # pylint: disable=assigning-non-slot
         g.user = security_manager.find_user(username="admin")
 
         dataset_ids = [id_ for (id_,) in db.session.query(SqlaTable.id).all()]
@@ -135,25 +133,23 @@ if feature_flags.get("VERSIONED_EXPORT"):
     @click.option(
         "--path",
         "-p",
-        required=True,
         help="Path to a single ZIP file",
     )
     @click.option(
         "--username",
         "-u",
-        required=True,
+        default=None,
         help="Specify the user name to assign dashboards to",
     )
     def import_dashboards(path: str, username: Optional[str]) -> None:
         """Import dashboards from ZIP file"""
         # pylint: disable=import-outside-toplevel
-        from superset.commands.importers.v1.utils import get_contents_from_bundle
-        from superset.dashboards.commands.importers.dispatcher import (
+        from superset.commands.dashboard.importers.dispatcher import (
             ImportDashboardsCommand,
         )
+        from superset.commands.importers.v1.utils import get_contents_from_bundle
 
         if username is not None:
-            # pylint: disable=assigning-non-slot
             g.user = security_manager.find_user(username=username)
         if is_zipfile(path):
             with ZipFile(path) as bundle:
@@ -180,10 +176,8 @@ if feature_flags.get("VERSIONED_EXPORT"):
     def import_datasources(path: str) -> None:
         """Import datasources from ZIP file"""
         # pylint: disable=import-outside-toplevel
+        from superset.commands.dataset.importers.dispatcher import ImportDatasetsCommand
         from superset.commands.importers.v1.utils import get_contents_from_bundle
-        from superset.datasets.commands.importers.dispatcher import (
-            ImportDatasetsCommand,
-        )
 
         if is_zipfile(path):
             with ZipFile(path) as bundle:
@@ -308,7 +302,7 @@ else:
     def import_dashboards(path: str, recursive: bool, username: str) -> None:
         """Import dashboards from JSON file"""
         # pylint: disable=import-outside-toplevel
-        from superset.dashboards.commands.importers.v0 import ImportDashboardsCommand
+        from superset.commands.dashboard.importers.v0 import ImportDashboardsCommand
 
         path_object = Path(path)
         files: list[Path] = []
@@ -319,7 +313,6 @@ else:
         elif path_object.exists() and recursive:
             files.extend(path_object.rglob("*.json"))
         if username is not None:
-            # pylint: disable=assigning-non-slot
             g.user = security_manager.find_user(username=username)
         contents = {}
         for path_ in files:
@@ -358,7 +351,7 @@ else:
     def import_datasources(path: str, sync: str, recursive: bool) -> None:
         """Import datasources from YAML"""
         # pylint: disable=import-outside-toplevel
-        from superset.datasets.commands.importers.v0 import ImportDatasetsCommand
+        from superset.commands.dataset.importers.v0 import ImportDatasetsCommand
 
         sync_array = sync.split(",")
         sync_columns = "columns" in sync_array
