@@ -14,7 +14,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-# pylint: disable=invalid-name, no-self-use, too-few-public-methods, too-many-arguments
+# pylint: disable=invalid-name, too-few-public-methods, too-many-arguments
 from __future__ import annotations
 
 from typing import Any, Callable, TYPE_CHECKING
@@ -24,9 +24,9 @@ from jinja2 import TemplateError
 from jinja2.meta import find_undeclared_variables
 
 from superset import is_feature_enabled
+from superset.commands.sql_lab.execute import SqlQueryRender
 from superset.errors import SupersetErrorType
 from superset.sql_parse import ParsedQuery
-from superset.sqllab.commands.execute import SqlQueryRender
 from superset.sqllab.exceptions import SqlLabException
 from superset.utils import core as utils
 
@@ -58,11 +58,7 @@ class SqlQueryRenderImpl(SqlQueryRender):
                 database=query_model.database, query=query_model
             )
 
-            parsed_query = ParsedQuery(
-                query_model.sql,
-                strip_comments=True,
-                engine=query_model.database.db_engine_spec.engine,
-            )
+            parsed_query = ParsedQuery(query_model.sql, strip_comments=True)
             rendered_query = sql_template_processor.process_template(
                 parsed_query.stripped(), **execution_context.template_params
             )
