@@ -26,7 +26,7 @@ from flask_appbuilder.security.decorators import has_access_api
 from flask_babel import lazy_gettext as _
 
 from superset import db, event_logger
-from superset.charts.commands.exceptions import (
+from superset.commands.chart.exceptions import (
     TimeRangeAmbiguousError,
     TimeRangeParseFailError,
 )
@@ -53,7 +53,7 @@ class Api(BaseSupersetView):
     @expose("/v1/query/", methods=("POST",))
     def query(self) -> FlaskResponse:
         """
-        Takes a query_obj constructed in the client and returns payload data response
+        Take a query_obj constructed in the client and returns payload data response
         for the given query_obj.
 
         raises SupersetSecurityException: If the user cannot access the resource
@@ -75,7 +75,7 @@ class Api(BaseSupersetView):
     @expose("/v1/form_data/", methods=("GET",))
     def query_form_data(self) -> FlaskResponse:
         """
-        Get the formdata stored in the database for existing slice.
+        Get the form_data stored in the database for existing slice.
         params: slice_id: integer
         """
         form_data = {}
@@ -94,7 +94,7 @@ class Api(BaseSupersetView):
     @rison(get_time_range_schema)
     @expose("/v1/time_range/", methods=("GET",))
     def time_range(self, **kwargs: Any) -> FlaskResponse:
-        """Get actually time range from human readable string or datetime expression"""
+        """Get actually time range from human-readable string or datetime expression."""
         time_range = kwargs["rison"]
         try:
             since, until = get_since_until(time_range)
@@ -105,7 +105,7 @@ class Api(BaseSupersetView):
             }
             return self.json_response({"result": result})
         except (ValueError, TimeRangeParseFailError, TimeRangeAmbiguousError) as error:
-            error_msg = {"message": _("Unexpected time range: %s" % error)}
+            error_msg = {"message": _(f"Unexpected time range: {error}")}
             return self.json_response(error_msg, 400)
 
     def get_query_context_factory(self) -> QueryContextFactory:
